#!/bin/bash

baseUrl="https://svs.portal64.de/ergebnisse/2019"
destDir="data/extern"
currentDir=$(pwd)
contentDirName="data"
contentAbsDir="$currentDir/$contentDirName"
cookies="$destDir/cookies.txt"

memberlist=data/extern/memberlist

calculateDwz() {
	while read line; do
		name=$(echo $line | awk -F';;' ' { print $1 }')
		dwz=$(echo $line | awk -F';;' ' { print $2 }')
		oppDwz=$(echo $line | awk -F';;' ' { print $3 }')
		results=$(echo $line | awk -F';;' ' { print $4 }')
		#echo $results
		if [ ! -z $oppDwz ]; then
			nameFormatted=$(echo $name | sed 's/, /,/g')
			age=$(grep "$nameFormatted" "$memberlist" | awk -F';;' '{ print $2 }')
			index=$(grep "$nameFormatted" "$memberlist" | awk -F';;' '{ print $3 }')
			if [ -z $dwz ]; then
				newDwz=$(./config/scripts/dwz-calculator.sh -b $age -d 0 -c 0 -o $oppDwz -r $results)
			else
				newDwz=$(./config/scripts/dwz-calculator.sh -b $age -d $dwz -c $index -o $oppDwz -r $results)
			fi			
			echo "$name;;$age;;$dwz;;$newDwz"
		else
			echo "$name;;$age;;$dwz;;;;;;"
		fi
	done < /dev/stdin
}

# see if script is executed at the correct location
if [ ! -e "$contentAbsDir" ]; then
	echo "execute this script from usv-tu-schach main directory with ./config/scripts/retrieve-external-data.sh"
	exit 1;
fi
#mftid=12333&submit=anzeigen

mannschaft1() {
	mSlug="1-mannschaft"
	urlTable="https://www.schachbund.de/SchachBL/bedh.php?liga=bl"
	urlLineup="https://www.schachbund.de/SchachBL/bedm.php?liga=bl&nummer=5"
	urlEvent="https://www.schachbund.de/SchachBL/bedt.php?liga=bl"
}
mannschaft2() { mSlug="2-mannschaft"; mNumber=1733; mftid=12069; }
mannschaft3() { mSlug="3-mannschaft"; mNumber=1733; mftid=12051; }
mannschaft4() { mSlug="4-mannschaft"; mNumber=1735; mftid=12089; }
mannschaft5() { mSlug="5-mannschaft"; mNumber=1759; mftid=12295; }
mannschaft6() { mSlug="6-mannschaft"; mNumber=1761; mftid=12333; }

convertToUtf8() { iconv -f ISO_8859-15 -t utf-8; }
#------------------------------------------------ Extracting ----------------------------------------------------------
extractTable() { sed -n -e '/<table.*>/,/<\/table>/p'; }
extractTeamTable() { sed -n -e "/<table.*>/{:a;N;/<\/table>/!ba; /mannschaft/p}"; }
extractSpecificTable() { sed -n -e "/<table.*>/{:a;N;/<\/table>/!ba; /USV TU Dresden $1/p}"; }
extractTrWithSearch() { sed -n -e "/<tr>/{:a;/Runde/{p;d};N;/<\/tr>/!ba; /.*USV TU Dresden $1.*/p}"; }
extractTrWithInTbody() { sed -n -e '/<tbody>/,/<\/tbody>/{/<tr>/,/<\/tr>/p}'; }
extractTrWithVariableSearch() { sed -n -e "/<tr>/{:a;N;/<\/tr>/!ba; /$1/p; }"; }
extractTrOfEveryFile() { sed -n '/<tr>/{:a;N;/<\/tr>/!ba; /td/{s/\n/\;\;/g;p}}' $1; }
extractDl() { sed -n '/<dl class=/,/<\/dl>/p'; }
extractDwz() { sed 's/<dt>\([^\;]*\);.*DWZ: \([^)]*\)).*/\1;\2;/'; }
extractResultLines() { sed -n 's/.*erg">\([^<]*\)<.*/\1/p'; }
extractResultForTeams() { sed -n "/<tr [^>]*>/{:a;N;/<\/tr>/!ba; /$1/{/$2/p}}"; }
#------------------------------------------------ Removing ------------------------------------------------------------
removeLinks() { sed -e 's/<a [^>]*>//;s/<\/a>//'; }
removeTbody() { sed -e '/<tbody class\="foot">/,/<\/tbody>/d'; }
removeTr() { sed '/<tr>/d;/<\/tr>/d'; }
removeBlanksInFront() { sed -e 's/[[:blank:]]*\(.*\)/\1/'; }
#removeBlanksInFront() { sed -n "/<table.*>/,/<\/table>/{s/^[[:blank:]]*\(<.*$\)/\1/;p}"; }
removeBlankLines() { sed '/^[[:blank:]]*$/d'; } # sed '/./!d'
removeSpecialTd() { sed -e '/<td colspan/d'; }
removeNotUsedTd() { sed -e '/<td> - <\/td>/d'; }
removeConcreteTags() { sed -e '/<td >.\{2\}<\/td>/d;/&minus/d;/hospitant/d;/ausrichter/d;/schiedsrichter/d'; }
removeTrInsideBody() { sed '/<tbody>/,/<\/tbody>/{s/^.*<tr [^>]*>.*$//;s/^<\/tr>.*$//}' | removeBlankLines; }
removeEmptyTdLine() { sed '/;<td><\/td>/d'; }
removeUnusedTh() { sed -n '/table/p;/tbody/,/tbody/p;/<thead.*>/{:a;N;/Maßgebliche/!ba; s/^.*$/&\n<\/tr>\n<\/thead>/; p}';}
removeLinesWithoutColon() { sed '/\:/!d'; }
removeAllButDwz() { sed '/<span>/s/.*DWZ: \([[:digit:]]\{3,4\}\).*/<span>\1<\/span>/'; }
removeSpans() { sed '/<span>/{H;/^\n$/!d}; x; s/<\/span>$/;/g; s/<\/span>\n/,/g; s/<span>//g;'; }
removeNewLinesAfterSemiColon() { sed '/./{:a;N;$!ba; s/\;\n/\;/g}'; }
removeSemiColonAtLineEnd() { sed 's/^\(.*\);$/\1/'; }
removeNotPlayedResults() { sed '/<span>+/d; /<span>-/d'; }
reduceTrToOneLine() { sed '/<tr>/{:a;N;/<\/tr>/!ba; s/\n//g}'; }
resultOnOneLine() { sed 'N;s/\n/:/'; }
#------------------------------------------------ Inserting -----------------------------------------------------------
insertClassForUsv() { sed "s/<td>\(USV TU Dresden $1[^<]*\)<\/td>/<td class\=\"usv\">\1<\/td>/g"; }
insertEventTableHead() { sed '1i <table class\="termine">\n<thead>\n<tr>\n<th>Datum<\/th>\n<th>Uhrzeit<\/th>\n<th>Heim<\/th>\n<th>Gast<\/th>\n<th>Ergebnis<\/th>\n<\/tr>\n<\/thead>\n<tbody>'; }
insertTableFoot() { sed '$a<\/tbody>\n<\/table>'; }
insertLineUpTableHead() { sed '1i <table class="aufstellung">\n<thead>\n<tr>\n<th>Name</th>\n<th>Geburstag</th>\n<th>DWZ</th>\n<th>Punkte</th>\n<th> +/- </th>\n<th>DWZ neu</th>\n</tr>\n</thead>\n<tbody>'; }
insertLineEvery5thLine() { sed -e '0~6s/.*/&\n/'; }
insertLineEvery5thLineInsideBody() { sed '/tbody/,/tbody/{1~5s/.*/&\n/}'; }
insertEmptyTdWithHead() { sed '/<thead>/,/<\/thead>/{s/<\/tr>/<th>Ergebnis<\/th>\n<\/tr>/};/<tbody>/,/<\/tbody>/{s/<\/tr>/<td><\/td>\n<\/tr>/}'; }
insertLineBeforDt() { sed 's/<dt>.*/\n&/'; }
insertLineAfterLastLine() { sed '${s/$/\n/}'; }
insertClassForDwzChange() { sed 's/<td>+/<td class="positive">+/; s/<td>-/<td class="negative">-/;'; }
insertDecimalPlace() { sed 's/\(<td>[^,]*\) aus/\1,0 aus/'; } 
#------------------------------------------------ Wrapping ------------------------------------------------------------
wrapEveryNthLineWithTr() { insertLineEvery5thLine | sed '/./{H;$!d} ; x ; s/^/<tr>/ ; s/$/\n<\/tr>/'; }
wrapEveryTdLineInTr() { sed 's/^\;\(.*\)/<tr>\n\1\n<\/tr>/'; }
wrapLineInTrAndColonInTd() { sed 's/^/<tr>\n<td>/; s/$/<\/td>\n<\/tr>/; s/\;\;/<\/td>\n<td>/g'; }
#------------------------------------------------ Replacing -----------------------------------------------------------
renameUsv() { sed 's/\(<td>USV TU Dresden\)\(<\/td>\)/\1 1\2/'; }
formatDate() { sed -e 's/<th[^>]*>Runde \([^[[:blank:]]]*\)[[:blank:]].* am \(.*\) um \(.*\) Uhr/<td>\2<\/td>\n<td>\3<\/td>/'; }
formatYearTo4Digit() { sed -e 's/\.\([[:digit:]]\{2\}\)</\.20\1</'; }
setTableClass() { sed -e 's/<table [^>]\+>/\<table class\="liga-tabelle">/g'; }
setLineupClass() { sed -e 's/<table [^>]\+>/\<table class\="aufstellung">/g'; }
cleanTds() { sed -e 's/.*<td [^>]*>/<td>/'; }
cleanTr() { sed -e 's/<tr [^>]*>/<tr>/'; }
replaceTdNewLineWithSemiColon() { sed -n '/table/,/tbody/{p;d};/tbody/p;/<td>/{H;$!d} ; x ; s/\n/\;/g;p' | removeBlankLines; }
replaceSemiColonWithNewLine() { sed 's/\;/\n/g'; }
replaceTrTdAndNewLines() { sed 's/<tr>\;\;//;s/\;\;<\/tr>//;s/<td>//g;s/<\/td>//g'; }
replaceHalfPoint() { sed 's/\&frac12\;/0.5/g'; }
replaceSemiColonWithDelimiter() { sed 's/\;/\;\;/g'; }
replaceResultNumbers() { sed 's/0\.5\:0\.5/0\.5/g;s/1\:0/1/g;s/0\:1/0/g'; }
replaceResult() { sed 's/\([[:digit:]]\)\/\([[:digit:]]\)/\1 aus \2/'; }
replaceHalfWithDecimal() { sed 's/½/,5/g'; }
replaceTrTdWithDelimiter() { sed 's/<tr><td>//g; s/<\/td><td>/\;\;/g; s/<\/td><\/tr>//g'; }
replaceSgLeipzig() { sed 's/Schachgemeinschaft/Sg/g'; }
#formatFile() { vim --cmd "argdo setf html | execute 'normal! gg=G' | update " "$1" --cmd quit > /dev/null 2>&1; }
#------------------------------------------------ Special -------------------------------------------------------------
putEverySecondLineToEnd() { sed -n '1~2{/\;<td>/bu};/<\/tbody>/ba;p;d;:u;H;d;:a;H;x;s/^\n\(.*\)$/\1/;p;d;'; }
sortLines() { sort -k3n -k2n -k1n -k5n; }
separateDateDigits() { sed 's/\([[:digit:]]\{2\}\)\.\([[:digit:]]\{2\}\)\.\([[:digit:]]\{4\}\)\;\;\([^\:]*\)\:\(.*\)/\1 \2 \3 \;\; \4 \5/'; }
rejoinDateDigits() { sed 's/\([[:digit:]]\{2\}\) \([[:digit:]]\{2\}\) \([[:digit:]]\{4\}\) \;\; \([^ ]*\) \(.*\)/\1\.\2\.\3\;\;\4\:\5/'; }
accumulateResults() { sed -n '/./{/<span>[[:digit:]].*/{H;$!d};p;};/^[[:blank:]]*$/{H;x;s/\n//;s/\n/,/g;s/<\/span>,$/<\/span>\n/;s/<span>//g;s/<\/span>//g;p;d}'; }
putNotPlayedResultsOnPrevLine() { sed '/<span>/{:a;N;/./!ba; s/\n<span>-/<span>-/g; s/\n<span>+/<span>+/g }'; }

catchResultForEvent() {
	wget --keep-session-cookies --save-cookies "$cookies" -q -O - https://www.schachbund.de/SchachBL/ticker.php > /dev/null
	while read line; do
		url="https://www.schachbund.de/SchachBL/ticker.php"
		date=$(echo "$line" | awk -F';;' ' { print $1 }')
		time=$(echo "$line" | awk -F';;' ' { print $2 }')
		home=$(echo "$line" | awk -F';;' ' { print $3 }')
		away=$(echo "$line" | awk -F';;' ' { print $4 }')
		day=$(echo "$date" | awk -F'.' ' { print $1 }')
		month=$(echo "$date" | awk -F'.' ' { print $2 }')
		year=$(echo "$date" | awk -F'.' ' { print $3 }')
		amDate="$year-$month-$day"		
		nowTimestamp=$(date '+%s')
		dateTimestamp=$(date -d $amDate '+%s')
		if [ $dateTimestamp -le $nowTimestamp ]; then
			#wget -q -O - https://www.schachbund.de/SchachBL/ticker.php?auswahl_spieltag=2019-11-24 | sed -n '/<tr [^>]*>/{:a;N;/<\/tr>/!ba; /USV TU Dresden/{/Baden-Baden/p}}' | sed -e 's/<a [^>]*>//;s/<\/a>//' | sed 's/½/,5/g' | sed -n 's/.*erg">\([^<]*\)<.*/\1/p' | sed 'N;s/\n/:/'
			result=$(wget --load-cookies "$cookies" -q -O - "$url?auswahl_spieltag=$amDate" | extractResultForTeams "$home" "$away" | removeLinks | 
			replaceHalfWithDecimal | 
			extractResultLines | 
			resultOnOneLine)
			echo "$line;;$result"
		else 
			echo "$line;;"
		fi
	done < /dev/stdin
	if [ -f $cookies ]; then rm $cookies; fi
}

queryDatabase() {
	mysql -u schach -pPASSWORDCHANGED schach -B --silent -e "$1"
}

insertEventCategoryIntoDatabase() {
	selectCat=$(queryDatabase 'Select term_id from wp_terms where name = "'$1'";') || $(echo "Error executing query!"; exit 1)
	if [ -z "$selectCat" ]; then
		echo "Category $1 is not in database! Creating ..."
		termId=$(queryDatabase "INSERT INTO wp_terms (name, slug, term_group) VALUES ('"$1"', '"$1"', 0); SELECT LAST_INSERT_ID();");
		queryDatabase "INSERT INTO wp_term_taxonomy (term_id, taxonomy, description, parent, count) VALUES ($termId, 'event-category', '', 0, 0);" || $(echo "Error executing query!"; exit 1);
	else
		echo "Category $1 is already in database! "
		termId=$selectCat;
	fi
	termTaxId=$(queryDatabase 'Select term_taxonomy_id from wp_term_taxonomy inner join wp_terms on wp_term_taxonomy.term_id=wp_terms.term_id where name="'$1'";') || $(echo "Error executing query!"; exit 1)
}

insertEventIntoDatabase() {
	insertEventCategoryIntoDatabase "spieltage"
	while read line; do
		date=$(echo "$line" | awk -F';;' ' { print $1 }')
		time=$(echo "$line" | awk -F';;' ' { print $2 }')
		home=$(echo "$line" | awk -F';;' ' { print $3 }')
		away=$(echo "$line" | awk -F';;' ' { print $4 }')
		day=$(echo "$date" | awk -F'.' ' { print $1 }')
		month=$(echo "$date" | awk -F'.' ' { print $2 }')
		year=$(echo "$date" | awk -F'.' ' { print $3 }')
		
		amDate="$year-$month-$day"		
		nowTimestamp=$(date '+%Y-%m-%d %H:%M:%S')
		dateTimestamp=$(date -d "$amDate $time" '+%Y-%m-%d %H:%M:%S')
		title="$home -- $away"
		
		homeContains=".*USV TU Dresden.*$"
		if [[ $home =~ $homeContains ]]; then 
			homeString="Das Spiel wird zu Hause ausgetragen!"
		else
			homeString="Wir Spielen auswärts bei $home!"
		fi
		selectInserted=$(cat <<-END
				Select post_title,StartDate,StartTime,EndDate,FinishTime from wp_posts 
				Right Join wp_eo_events on ID = post_id where post_title = "$title" 
				and StartDate = "$amDate" and EndDate = "$amDate";
				END
				)
		echo "------------------------------------------"
		selectInsertedRes=$(queryDatabase "$selectInserted") || $(echo "Error executing query!"; exit 1)
		if [ -z "$selectInsertedRes" ]; then
			echo "Inserting event with title $title into the database!"
				insertPost=$(cat <<-END
						INSERT INTO wp_posts (post_author,post_date,post_date_gmt,post_content,post_content_filtered,post_title,
						post_excerpt,post_status,post_type,comment_status,ping_status,post_password,post_name,to_ping,pinged,
						post_modified,post_modified_gmt,post_parent,menu_order,post_mime_type,guid) VALUES 
						(1,"$nowTimestamp",'0000-00-00 00:00:00',"Das Spiel findet am $date um $time statt. $homeString",
						'',"$title",'','publish','event','closed','closed','','','','',
						"$nowTimestamp",'0000-00-00 00:00:00',0,0,'',''); SELECT LAST_INSERT_ID();
						END
						)
				id=$(queryDatabase "$insertPost") || $(echo "Error executing query!"; exit 1)
				insertEvent=$(cat <<-END 
						UPDATE wp_posts SET post_name = "$id" WHERE ID = $id;
						INSERT INTO wp_eo_events (post_id, StartDate, StartTime, EndDate, FinishTime, event_occurrence) 
						VALUES ($id, "$amDate", "$time", "$amDate", "$time", '0');
						END
						)
				queryDatabase "$insertEvent" || $(echo "Error executing query!"; exit 1)
				insertPostMeta=$(cat <<-END
						INSERT INTO wp_term_relationships (object_id, term_taxonomy_id) VALUES ($id, $termTaxId);
						UPDATE wp_term_taxonomy SET count = count + 1 WHERE term_taxonomy_id = $termTaxId;
						INSERT INTO wp_postmeta (post_id, meta_key, meta_value) VALUES 
						("$id", '_eventorganiser_schedule_start_start', "$dateTimestamp");
						INSERT INTO wp_postmeta (post_id, meta_key, meta_value) VALUES ("$id", '_eventorganiser_event_schedule', 
						'a:7:{s:7:\"all_day\";i:0;s:8:\"schedule\";s:4:\"once\";s:13:\"schedule_meta\";s:0:\"\";s:9:\"frequency\";i:1;s:7:\"exclude\";a:0:{}s:7:\"include\";a:0:{}s:12:\"duration_str\";s:38:\"+0 days +1 hours +0 minutes +0 seconds\";}'
						);
						END
						)						
				queryDatabase "$insertPostMeta"	
		else
			echo "Event with title $title is already in the database!"
		fi
	done < /dev/stdin
}

i=1
while [ "$i" -ne 7 ]
do
	eval "mannschaft$i"
	mkdir -p $destDir
	tableFile=$destDir/$mSlug-tabelle.html
	lineupFile=$destDir/$mSlug-aufstellung.html
	eventFileName=$mSlug-terminliste.html
	eventsFile=$destDir/termine
	eventFile=$destDir/$eventFileName
	resultFile="$destDir/beforeDWZ-$i"
	eventFileNames=""
	if [ $i -ne 1 ]; then
		urlTable=$baseUrl/$mNumber/tabelle/plain/
		urlLineup=$baseUrl/$mNumber/aufstellungen/plain/
		urlEvent=$baseUrl/$mNumber/termin/plain/
		urlResults=$baseUrl/$mNumber/einzelergebnisse/
	fi
	if [ $i -ne 1 ]; then
		echo "Downloading league table for team $i"
		wget -q -O - $urlTable | convertToUtf8 | removeBlanksInFront | extractTable | removeLinks | removeBlankLines | 
		setTableClass | replaceSgLeipzig | insertClassForUsv $i > $tableFile 

#		echo "Downloading lineup table for team $i"
#		#wget -O - https://svs.portal64.de/ergebnisse/2019/1735/aufstellungen/plain/ | iconv -f ISO_8859-15 -t utf-8 | sed -n -e '/<table.*>/{:a;N;/<\/table>/!ba; /USV TU Dresden 4/p}' | sed -e '/<tbody class\="foot">/,/<\/tbody>/d' | sed -n -e "/<table.*>/,/<\/table>/{s/^[[:blank:]]*\(<.*$\)/\1/;p}" | sed -e '/^[[:blank:]]*$/d' |  sed -n -e '/table/p;/tbody/,/tbody/p;/<thead.*>/{:a;N;/Maßgebliche/!ba; s/^.*$/&\n<\/tr>\n<\/thead>/; p}' | sed -e '/<tbody>/,/<\/tbody>/{s/^.*<tr [^>]*>.*$//;s/^<\/tr>.*$//}' | sed -e '/^[\n]*$/d' | sed -e 's/^\(.*\)<td[^>]*>\(.*\)<\/td>/\1<td>\2<\/td>/' | sed -e '/tbody/,/tbody/{1~5s/.*/&\n/}' |  sed -n -e '/table/,/tbody/{p;d};/tbody/p;/<td>/{H;$!d} ; x ; s/\n/\;/g;p' | sed -e '/^[\n]*$/d' | sed -n -e '1~2{/\;<td>/bu};/<\/tbody>/ba;p;d;:u;H;d;:a;H;x;s/^\n\(.*\)$/\1/;p;d;' | sed '/;<td><\/td>/d' | sed 's/^\;\(.*\)/<tr>\n\1\n<\/tr>/' | sed 's/\;/\n/g' | sed 's/<table [^>]\+>/\<table class\="aufstellung">/g'
#		wget -q -O - $urlLineup | convertToUtf8 | extractSpecificTable $i | removeTbody | removeBlanksInFront | 
#		removeBlankLines | removeUnusedTh | removeTrInsideBody | cleanTds | insertLineEvery5thLineInsideBody |
#		replaceTdNewLineWithSemiColon | putEverySecondLineToEnd | removeEmptyTdLine | wrapEveryTdLineInTr | 
#		replaceSemiColonWithNewLine | setLineupClass > $lineupFile

		#cat test | sed -n '/<dl class=/,/<\/dl>/p' |  sed -e 's/[[:blank:]]*\(.*\)/\1/' | sed '/^[[:blank:]]*$/d' | sed 's/<dt>.*/\n&/' | sed '/\:/!d' | sed 's/\&frac12\;/0.5/g' | 
		#sed 's/<dt>.*/\n&/' | sed '${s/$/\n/}' 
		# sed '/<span>/{:a;N;/./!ba; s/\n<span>-/<span>-/g; s/\n<span>+/<span>+/g }' | sed '/<span>+/d; /<span>-/d'
		# | sed -n '/./{/<span>[[:digit:]].*/{H;$!d};p;};/^[[:blank:]]*$/{H;x;s/\n//;s/\n/,/g;s/<\/span>,$/<\/span>\n/;s/<span>//g;s/<\/span>//g;p;d}' |
		# sed '/<span>/s/.*DWZ: \([[:digit:]]\{4\}\).*/<span>\1<\/span>/' |  sed '/<span>/{H;/^\n$/!d}; x; s/<\/span>$/;/g; s/<\/span>\n/,/g; s/<span>//g;' | 
		# sed 's/<dt>\([^\;]*\);.*DWZ: \([^)]*\)).*/\1;\2;/' | sed '/./{:a;N;$!ba; s/\;\n/\;/g}' | sed '/./!d' | sed 's/^\(.*\);$/\1/' | sed 's/\;/\;\;/g' | 
		# sed 's/0\.5\:0\.5/0\.5/g;s/1\:0/1/g;s/0\:1/0/g'		
		
		echo "Downloading results table for team $i"
		wget --post-data "mftid=$mftid&submit=anzeigen" -q -O - $urlResults | convertToUtf8 | extractDl | 
		removeBlanksInFront | removeBlankLines | removeLinesWithoutColon | replaceHalfPoint | insertLineBeforDt | 
		insertLineAfterLastLine | putNotPlayedResultsOnPrevLine | removeNotPlayedResults | accumulateResults | 
		removeAllButDwz | removeSpans | extractDwz | removeNewLinesAfterSemiColon | removeBlankLines | 
		removeSemiColonAtLineEnd | replaceSemiColonWithDelimiter | replaceResultNumbers > "$resultFile"
		cat "$resultFile" | calculateDwz | wrapLineInTrAndColonInTd | insertClassForDwzChange | replaceResult | 
		insertDecimalPlace | insertLineUpTableHead | insertTableFoot > $lineupFile
		
		#sed 's/^/<tr>\n<td>/; s/$/<\/td>\n<\/tr>/; s/\;\;/<\/td>\n<td>/g' | sed 's/<td>+/<td class="positive">+/; s/<td>-/<td class="negative">-/; s/\([[:digit:]]\)\/\([[:digit:]]\)/\1 aus \2/'
			
		echo "Downloading events for team $i"
		#wget -q -O - https://svs.portal64.de/ergebnisse/2019/1735/termin/plain/ | iconv -f ISO_8859-15 -t utf-8 | sed -n "/<table.*>/,/<\/table>/{s/^[[:blank:]]*\(<.*$\)/\1/;p}" | sed '/^[[:blank:]]*$/d' | sed 's/<tr [^>]*>/<tr>/' | sed -e '/<td colspan/d' | sed -n -e '/<tr>/{:a;/Runde/{p;d};N;/<\/tr>/!ba; /.*USV TU Dresden 4.*/p}' | sed -e 's/<th[^>]*>Runde \([^[[:blank:]]]*\)[[:blank:]].* am \(.*\) um \(.*\) Uhr/<td>\2<\/td>\n<td>\3<\/td>/' | sed '/<tr>/d;/<\/tr>/d' | sed -e '0~6s/.*/&\n/' | sed '/./{H;$!d} ; x ; s/^/<tr>/ ; s/$/\n<\/tr>/' | sed -e '/<td> - <\/td>/d' | sed 's/<a [^>]*>//;s/<\/a>//' | sed -e 's/.*<td [^>]*>/<td>/' | sed '1i <table class\="termine">\n<thead>\n<tr>\n<th>Datum<\/th>\n<th>Uhrzeit<\/th>\n<th>Heim<\/th>\n<th>Gast<\/th>\n<th>Ergebnis<\/th>\n<\/tr>\n<\/thead>\n<tbody>' | sed '$a<\/tbody>\n<\/table>'
		wget -q -O - $urlEvent | convertToUtf8 | removeBlanksInFront | removeBlankLines | cleanTr | removeSpecialTd | 
		extractTrWithSearch $i | formatDate | removeTr | wrapEveryNthLineWithTr | removeNotUsedTd | 
		removeLinks | cleanTds | replaceSgLeipzig | insertEventTableHead | insertTableFoot > $eventFile
	else
		echo "Downloading table for team $i"	
		wget -q -O - $urlTable | extractTable | removeLinks | removeBlankLines | setTableClass |
		insertClassForUsv $i > $tableFile

		echo "Downloading lineup for team $i"
		wget -q -O - $urlLineup | extractTeamTable | removeLinks | removeBlankLines | 
		setLineupClass > $lineupFile

		echo "Downloading events for team $i"
		#wget -q -O - 'https://www.schachbund.de/SchachBL/bedt.php?liga=bl' | sed -e 's/<a [^>]*>//;s/<\/a>//' | sed -e 's/<tr [^>]*>/<tr>/' | sed -e 's/\.\([[:digit:]]\{2\}\)</\.20\1</' | sed -e '/<td >.\{2\}<\/td>/d;/&minus/d;/hospitant/d;/ausrichter/d;/schiedsrichter/d' | sed -n -e '/<tr>/{:a;N;/<\/tr>/!ba; /USV TU Dresden/p; }' | sed -e 's/\(.*\)<td [^>]*>/\1<td>/' | sed -e 's/[[:blank:]]*\(.*\)/\1/' | sed '/<tr>/{:a;N;/<\/tr>/!ba; s/\n//g}' | sed 's/<tr><td>//g; s/<\/td><td>/\;\;/g; s/<\/td><\/tr>//g'
		wget -q -O - $urlEvent | removeLinks | cleanTr | formatYearTo4Digit | removeConcreteTags | 
		extractTrWithVariableSearch "USV TU Dresden" | cleanTds | removeBlanksInFront | reduceTrToOneLine | 
		replaceTrTdWithDelimiter | catchResultForEvent | wrapLineInTrAndColonInTd | renameUsv |
		insertEventTableHead | insertTableFoot > $eventFile
	fi
	echo "--------------------------------------------------"
	i=$((i + 1))
done
echo "Creating sorted events file"
#sed -n '/<tr>/{:a;N;/<\/tr>/!ba; /td/{s/\n/\;\;/g;p}}' data/extern/*-terminliste.html | sed 's/<tr>\;\;//;s/\;\;<\/tr>//;s/<td>//g;s/<\/td>//g' | sed 's/\([[:digit:]]\{2\}\)\.\([[:digit:]]\{2\}\)\.\([[:digit:]]\{4\}\)\;\;\([^\:]*\)\:\(.*\)/\1 \2 \3 \;\; \4 \5/' | sort -k3n -k2n -k1n -k5n | sed 's/\([[:digit:]]\{2\}\) \([[:digit:]]\{2\}\) \([[:digit:]]\{4\}\) \;\; \([^ ]*\) \(.*\)/\1\.\2\.\3\;\;\4\:\5/'
extractTrOfEveryFile "$destDir/*-terminliste.html" | replaceTrTdAndNewLines | separateDateDigits | sortLines |
rejoinDateDigits | insertEventIntoDatabase

exit 0;
